@@ -18,11 +18,6 @@ GVHistory::GVHistory (QWidget *parent, Qt::WindowFlags flags)
     OsDependent &osd = Singletons::getRef().getOSD ();
     osd.setDefaultWindowAttributes (this);
 
-    // Connect the log to this classes log.
-    QObject::connect (
-        ui->treeView, SIGNAL (log(const QString &, int)),
-        this        , SIGNAL (log(const QString &, int)));
-
     // Add all these actions to the action group
     actionGroup.addAction (ui->actionAll);
     actionGroup.addAction (ui->actionPlaced);
@@ -139,7 +134,6 @@ GVHistory::refreshFullInbox ()
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
     dbMain.setLastInboxUpdate (QDateTime::fromString ("2000-01-01",
                                                       "yyyy-MM-dd"));
-    dbMain.clearInbox ();
     refreshHistory ();
 }//GVHistory::refreshFullInbox
 
@@ -173,8 +167,8 @@ GVHistory::getHistoryDone (bool, const QVariantList &)
     QDateTime dtUpdate;
     if (dbMain.getLatestInboxEntry (dtUpdate))
     {
-        emit log (QString ("Latest inbox entry is : %1")
-                  .arg (dtUpdate.toString ()));
+        qDebug () << QString ("Latest inbox entry is : %1")
+                        .arg (dtUpdate.toString ());
         dbMain.setLastInboxUpdate (dtUpdate);
     }
 
